/* globals jest, describe, it, expect, beforeEach */
import React from 'react';
import { mount } from 'enzyme';
import Input from '../input';
import componentTest from './component';
var changeValue = function (inputNode, value) {
    var inputDOMNode = inputNode.getDOMNode();
    inputDOMNode.value = value;
    inputNode.simulate('change');
};
describe('The <Input /> component', function () {
    componentTest(Input);
    describe('the initial render of the form control', function () {
        it('is `type="text"` by default', function () {
            var wrapper = mount(React.createElement(Input, { name: "myTestInput", id: "testId" }));
            expect(wrapper.find('input').prop('type')).toEqual('text');
        });
        it('has an initial value passed by prop', function () {
            var wrapper = mount(React.createElement(Input, { name: "myTestInput", id: "myId", value: "Initial value" }));
            expect(wrapper.find('input').prop('value')).toEqual('Initial value');
        });
        it('has a placeholder value passed by prop', function () {
            var wrapper = mount(React.createElement(Input, { name: "myTestInput", id: "myId", value: "", placeholder: "My placeholder" }));
            expect(wrapper.find('input').prop('placeholder')).toEqual('My placeholder');
        });
    });
    describe('has basic accessibility features', function () {
        var wrapper;
        beforeEach(function () {
            wrapper = mount(React.createElement(Input, { name: "myTestInput", id: "myId", label: "My Label", value: "Initial value" }));
        });
        it('has an `id` attribute on the form control', function () {
            expect(wrapper.find('input').prop('id')).toEqual('myId');
        });
        it('has a matching `htmlFor` attribute on the label', function () {
            var id = wrapper.find('input').prop('id');
            var htmlFor = wrapper.find('label').prop('htmlFor');
            expect(htmlFor).toEqual(id);
        });
        // http://getbootstrap.com/css/#forms-help-text
        it('has an `aria-describedby` prop on the form control when help text is present', function () { });
        it('has an `aria-invalid="true"` prop on the form control when validation has failed', function () { });
        it('has an `aria-required="true"` prop on the form control when validation is required', function () { });
    });
    describe('Input components do this', function () {
        var onBlurProp;
        var changeCallbackProp;
        var onSetValueProp;
        var wrapper;
        beforeEach(function () {
            jest.useFakeTimers();
            onBlurProp = jest.fn();
            changeCallbackProp = jest.fn();
            onSetValueProp = jest.fn();
            wrapper = mount(React.createElement(Input, { name: "myTestInput", id: "myId", label: "My Label", value: "Initial value", blurCallback: onBlurProp, changeCallback: changeCallbackProp, onSetValue: onSetValueProp }));
        });
        // Test that this is a controlled component.
        it('updates the input value from props', function () {
            wrapper.setProps({ value: 'Changed value' });
            expect(wrapper.find('input').prop('value')).toEqual('Changed value');
        });
        it('executes `props.changeCallback` when the <input /> value changes', function () {
            /*
             * The following doesn't work, we have to set the node's value directly:
             *
             * TestUtils.Simulate.change(node, {currentTarget: {value: 'Changed value'}});
             *
             * @see https://github.com/facebook/react/issues/3151#issuecomment-74943529
             */
            expect(changeCallbackProp).not.toBeCalled();
            var inputNode = wrapper.find('input');
            changeValue(inputNode, 'Changed value');
            expect(changeCallbackProp).toBeCalled();
            expect(wrapper.find('input').prop('value')).toEqual('Changed value');
        });
        it('debounces `props.onSetValue`', function () {
            expect(changeCallbackProp).not.toBeCalled();
            expect(onSetValueProp).not.toBeCalled();
            var inputNode = wrapper.find('input');
            changeValue(inputNode, 'a');
            changeValue(inputNode, 'b');
            changeValue(inputNode, 'c');
            expect(changeCallbackProp).toBeCalled();
            expect(changeCallbackProp).toHaveBeenCalledTimes(3);
            /*
             * The `onSetValueProp` function should be called after a period of
             * 500ms (it is debounced for change events).
             */
            expect(onSetValueProp).not.toBeCalled();
            jest.runAllTimers();
            expect(onSetValueProp).toBeCalled();
            expect(onSetValueProp).toHaveBeenCalledTimes(1);
        });
    });
    describe('includes an `<InputGroup />` component when', function () {
        it('is triggered by an `addonBefore` prop', function () { });
        it('is triggered by an `addonAfter` prop', function () { });
        it('is triggered by an `buttonBefore` prop', function () { });
        it('is triggered by an `buttonAfter` prop', function () { });
    });
    describe('for "hidden" type', function () {
        it('doesn’t render a label', function () {
            var wrapper = mount(React.createElement(Input, { name: "myTestInput", id: "myId", type: "hidden", label: "My Label" }));
            expect(wrapper.find('label').length).toBe(0);
        });
    });
});
//# sourceMappingURL=input-test.js.map